#
# PySNMP MIB module APPN-TRAP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/APPN-TRAP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:05:44 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( dlurDlusSessnStatus, ) = mibBuilder.importSymbols("APPN-DLUR-MIB", "dlurDlusSessnStatus")
( appnPortOperState, appnIsInS2PNonFmdBytes, appnLocalTgCpCpSession, appnIsInSessUpTime, appnLocalTgOperational, appnIsInS2PFmdBytes, appnMIB, appnIsInP2SFmdBytes, appnObjects, appnIsInS2PFmdPius, appnIsInP2SFmdPius, appnLsOperState, appnCompliances, appnIsInS2PNonFmdPius, appnIsInP2SNonFmdBytes, appnGroups, appnIsInP2SNonFmdPius, ) = mibBuilder.importSymbols("APPN-MIB", "appnPortOperState", "appnIsInS2PNonFmdBytes", "appnLocalTgCpCpSession", "appnIsInSessUpTime", "appnLocalTgOperational", "appnIsInS2PFmdBytes", "appnMIB", "appnIsInP2SFmdBytes", "appnObjects", "appnIsInS2PFmdPius", "appnIsInP2SFmdPius", "appnLsOperState", "appnCompliances", "appnIsInS2PNonFmdPius", "appnIsInP2SNonFmdBytes", "appnGroups", "appnIsInP2SNonFmdPius")
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueSizeConstraint, ValueRangeConstraint, ConstraintsIntersection, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueSizeConstraint", "ValueRangeConstraint", "ConstraintsIntersection", "SingleValueConstraint")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( Gauge32, Counter64, Counter32, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, IpAddress, Integer32, ObjectIdentity, NotificationType, iso, ModuleIdentity, Unsigned32, MibIdentifier, TimeTicks, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Gauge32", "Counter64", "Counter32", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "IpAddress", "Integer32", "ObjectIdentity", "NotificationType", "iso", "ModuleIdentity", "Unsigned32", "MibIdentifier", "TimeTicks")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
appnTrapMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 34, 4, 0))
if mibBuilder.loadTexts: appnTrapMIB.setLastUpdated('9808310000Z')
if mibBuilder.loadTexts: appnTrapMIB.setOrganization('IETF SNA NAU MIB WG / AIW APPN MIBs SIG')
if mibBuilder.loadTexts: appnTrapMIB.setContactInfo('\n                        Bob Clouston\n                        Cisco Systems\n                        7025 Kit Creek Road\n                        P.O. Box 14987\n                        Research Triangle Park, NC 27709, USA\n                        Tel:    1 919 472 2333\n                        E-mail: clouston@cisco.com\n\n                        Bob Moore\n                        IBM Corporation\n                        4205 S. Miami Boulevard\n                        BRQA/501\n                        P.O. Box 12195\n                        Research Triangle Park, NC 27709, USA\n                        Tel:    1 919 254 4436\n                        E-mail: remoore@us.ibm.com\n                ')
if mibBuilder.loadTexts: appnTrapMIB.setDescription('This MIB module defines notifications to be generated by\n                network devices with APPN capabilities.  It presupposes\n                support for the APPN MIB.  It also presupposes\n                support for the DLUR MIB for implementations\n                that support the DLUR-related groups.')
appnIsrAccountingDataTrap = NotificationType((1, 3, 6, 1, 2, 1, 34, 4, 0, 1)).setObjects(*(("APPN-TRAP-MIB", "appnIsInP2SFmdPius"), ("APPN-TRAP-MIB", "appnIsInS2PFmdPius"), ("APPN-TRAP-MIB", "appnIsInP2SNonFmdPius"), ("APPN-TRAP-MIB", "appnIsInS2PNonFmdPius"), ("APPN-TRAP-MIB", "appnIsInP2SFmdBytes"), ("APPN-TRAP-MIB", "appnIsInS2PFmdBytes"), ("APPN-TRAP-MIB", "appnIsInP2SNonFmdBytes"), ("APPN-TRAP-MIB", "appnIsInS2PNonFmdBytes"), ("APPN-TRAP-MIB", "appnIsInSessUpTime"),))
if mibBuilder.loadTexts: appnIsrAccountingDataTrap.setDescription('When it has been enabled, this notification is generated by an\n          APPN node whenever an ISR session passing through the node is\n          taken down, regardless of whether the session went down\n          normally or abnormally.  Its purpose is to allow a management\n          application (primarily an accounting application) that is\n          monitoring the ISR counts to receive the final values of these\n          counts, so that the application can properly account for the\n          amounts the counts were incremented since the last time the\n          application polled them.  The appnIsInSessUpTime object\n          provides the total amount of time that the session was active.\n\n          This notification is not a substitute for polling the ISR\n          counts.  In particular, the count values reported in this\n          notification cannot be assumed to be the complete totals for\n          the life of the session, since they may have wrapped while the\n          session was up.\n\n          The session to which the objects in this notification apply is\n          identified by the fully qualified CP name and PCID that make up\n          the table index.  An instance of this notification will contain\n          exactly one instance of each of its objects, and these objects\n          will all belong to the same conceptual row of the\n          appnIsInTable.\n\n          Generation of this notification is controlled by the same\n          object in the APPN MIB, appnIsInGlobeCtrAdminStatus, that\n          controls whether the count objects themselves are being\n          incremented.')
appnLocalTgOperStateChangeTrap = NotificationType((1, 3, 6, 1, 2, 1, 34, 4, 0, 2)).setObjects(*(("APPN-TRAP-MIB", "appnLocalTgTableChanges"), ("APPN-TRAP-MIB", "appnLocalTgOperational"),))
if mibBuilder.loadTexts: appnLocalTgOperStateChangeTrap.setDescription("When it has been enabled, this notification makes it possible\n          for an APPN topology application to get asynchronous\n          notifications of local TG operational state changes,\n          and thus to reduce the frequency with which it polls\n          for these changes.\n\n          This notification is sent whenever there is a change to\n          the appnLocalTgOperational object in a row of the\n          appnLocalTgTable.  This notification is only sent for row\n          creation if the row is created with a value of 'true' for\n          appnLocalTgOperational.  This notification is only sent for\n          row deletion if the last value of appnLocalTgOperational was\n          'true'.  In this case, the value of appnLocalTgOperational\n          in the notification shall be 'false', since the deletion of\n          a row indicates that the TG is no longer operational.\n\n          The notification is more than a simple 'poll me now' indication.\n          It carries both a count of local TG topology changes, and the\n          current operational state itself.  The count of changes allows an\n          application to detect lost notifications, either when polling\n          or upon receiving a subsequent notification, at which point it\n          knows it must retrieve the entire appnLocalTgTable again.\n          This is the same count as used in the appnLocalCpCpStateChangeTrap.\n          A lost notification could indicate a local TG CP-CP session state\n          change or an operational state change.\n\n          Generation of this notification is controlled by the\n          appnTrapControl object.")
appnLocalTgCpCpChangeTrap = NotificationType((1, 3, 6, 1, 2, 1, 34, 4, 0, 3)).setObjects(*(("APPN-TRAP-MIB", "appnLocalTgTableChanges"), ("APPN-TRAP-MIB", "appnLocalTgCpCpSession"),))
if mibBuilder.loadTexts: appnLocalTgCpCpChangeTrap.setDescription("When it has been enabled, this notification makes it possible\n          for an APPN topology application to get asynchronous\n          notifications of local TG control-point to control-point (CP-CP)\n          session state changes, and thus to reduce the\n          frequency with which it polls for these changes.\n\n          This notification is sent whenever there is a change to\n          the appnLocalTgCpCpSession object but NOT the\n          appnLocalTgOperational object in a row of the appnLocalTgTable.\n          This notification is never sent for appnLocalTgTable row\n          creation or deletion.\n\n          The notification is more than a simple 'poll me now' indication.\n          It carries both a count of local TG topology changes, and the\n          current CP-CP session state itself.  The count of changes allows\n          an application to detect lost notifications, either when polling\n          or upon receiving a subsequent notification, at which point it\n          knows it must retrieve the entire appnLocalTgTable again.  This\n          is the same count as used in the appnLocalTgOperStateChangeTrap.\n          A lost notification could indicate a local TG CP-CP session\n          state change or an operational state change.\n\n          Generation of this notification is controlled by the\n          appnTrapControl object.")
appnPortOperStateChangeTrap = NotificationType((1, 3, 6, 1, 2, 1, 34, 4, 0, 4)).setObjects(*(("APPN-TRAP-MIB", "appnPortTableChanges"), ("APPN-TRAP-MIB", "appnPortOperState"),))
if mibBuilder.loadTexts: appnPortOperStateChangeTrap.setDescription("When it has been enabled, this notification makes it possible\n          for an APPN topology application to get asynchronous\n          notifications of port operational state changes, and thus to\n          reduce the frequency with which it polls for these changes.\n          This notification is only sent when a appnPortOperState has\n          transitioned to a value of 'active' or 'inactive'.\n\n          This notification is sent whenever there is a appnPortOperState\n          object transition to 'inactive' or 'active' state in the\n          appnPortTable.  This notification is only sent for row creation\n          if the row is created with a value of 'active' for\n          appnPortOperState.  This notification is only sent for\n          row deletion if the last value of appnPortOperState was\n          'active'.  In this case, the value of appnPortOperState\n          in the notification shall be 'inactive', since the deletion of\n          a row indicates that the port is no longer active.\n\n          The notification is more than a simple 'poll me now' indication.\n          It carries both a count of port table changes, and the\n          operational state itself.  The count of changes allows an\n          application to detect lost notifications, either when polling\n          or upon receiving a subsequent notification, at which point\n          it knows it must retrieve the entire appnPortTable again.\n\n          Generation of this notification is controlled by the\n          appnTrapControl object.")
appnLsOperStateChangeTrap = NotificationType((1, 3, 6, 1, 2, 1, 34, 4, 0, 5)).setObjects(*(("APPN-TRAP-MIB", "appnLsTableChanges"), ("APPN-TRAP-MIB", "appnLsOperState"),))
if mibBuilder.loadTexts: appnLsOperStateChangeTrap.setDescription("When it has been enabled, this notification makes it possible\n          for an APPN topology application to get asynchronous\n          notifications of link station operational state changes, and\n          thus to reduce the frequency with which it polls for these\n          changes.  This notification is only sent when a appnLsOperState\n          has transitioned to a value of 'active' or 'inactive'.\n\n          This notification is sent whenever there is a appnLsOperState\n          object transition to 'inactive' or 'active' state in the\n          appnLsTable.  This notification is only sent for row creation\n          if the row is created with a value of 'active' for\n          appnLsOperState.  This notification is only sent for\n          row deletion if the last value of appnLsOperState was\n          'active'.  In this case, the value of appnLsOperState\n          in the notification shall be 'inactive', since the deletion of\n          a row indicates that the link station is no longer active.\n\n          The notification is more than a simple 'poll me now' indication.\n          It carries both a count of link station table changes, and the\n          operational state itself.  The count of changes allows an\n          application to detect lost notifications, either when polling\n          or upon receiving a subsequent notification, at which point it\n          knows it must retrieve the entire appnLsTable again.\n\n          Generation of this notification is controlled by the\n          appnTrapControl object.")
dlurDlusStateChangeTrap = NotificationType((1, 3, 6, 1, 2, 1, 34, 4, 0, 6)).setObjects(*(("APPN-TRAP-MIB", "dlurDlusTableChanges"), ("APPN-TRAP-MIB", "dlurDlusSessnStatus"),))
if mibBuilder.loadTexts: dlurDlusStateChangeTrap.setDescription("When it has been enabled, this notification makes it possible\n          for an APPN topology application to get asynchronous\n          notifications of DLUR-DLUS session changes, and thus to reduce\n          the frequency with which it polls for these changes.\n\n          This notification is sent whenever there is a dlurDlusSessnStatus\n          object transition to 'inactive' or 'active' state in the\n          dlurDlusTable.  This notification is only sent for row creation\n          if the row is created with a value of 'active' for\n          dlurDlusSessnStatus.  This notification is only sent for\n          row deletion if the last value of dlurDlusSessnStatus was\n          'active'.  In this case, the value of dlurDlusSessnStatus\n          in the notification shall be 'inactive', since the deletion of\n          a row indicates that the session is no longer active.\n\n          The notification is more than a simple 'poll me now' indication.\n          It carries both a count of DLUR-DLUS table changes, and the\n          session status itself.  The count of changes allows an\n          application to detect lost notifications, either when polling\n          or upon receiving a subsequent notification, at which point it\n          knows it must retrieve the entire dlurDlusTable again.\n\n          Generation of this notification is controlled by the\n          appnTrapControl object.")
appnTrapObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 4, 1, 7))
appnTrapControl = MibScalar((1, 3, 6, 1, 2, 1, 34, 4, 1, 7, 1), Bits().clone(namedValues=NamedValues(("appnLocalTgOperStateChangeTrap", 0), ("appnLocalTgCpCpChangeTrap", 1), ("appnPortOperStateChangeTrap", 2), ("appnLsOperStateChangeTrap", 3), ("dlurDlusStateChangeTrap", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: appnTrapControl.setDescription("An object to turn APPN notification generation on and off.\n          Setting a notification type's bit to 1 enables generation of\n          notifications of that type, subject to further filtering\n          resulting from entries in the snmpNotificationMIB.  Setting\n          this bit to 0 disables generation of notifications of that\n          type.\n\n          Note that generation of the appnIsrAccountingDataTrap is\n          controlled by the appnIsInGlobeCtrAdminStatus object in\n          the APPN MIB:  if counts of intermediate session traffic\n          are being kept at all, then the notification is also enabled.")
appnLocalTgTableChanges = MibScalar((1, 3, 6, 1, 2, 1, 34, 4, 1, 7, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: appnLocalTgTableChanges.setDescription('A count of the number of times a row in the appnLocalTgTable\n          has changed status since the APPN node was last reinitialized.\n          This counter is incremented whenever a condition is detected\n          that would cause a appnLocalTgOperStateChangeTrap or\n          appnLocalTgCpCpChangeTrap notification to be sent, whether\n          or not those notifications are enabled.')
appnPortTableChanges = MibScalar((1, 3, 6, 1, 2, 1, 34, 4, 1, 7, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: appnPortTableChanges.setDescription('A count of the number of times a row in the appnPortTable\n          has changed status since the APPN node was last reinitialized.\n          This counter is incremented whenever a condition is detected\n          that would cause a appnPortOperStateChangeTrap notification\n          to be sent, whether or not this notification is enabled.')
appnLsTableChanges = MibScalar((1, 3, 6, 1, 2, 1, 34, 4, 1, 7, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: appnLsTableChanges.setDescription('A count of the number of times a row in the appnLsTable\n          has changed status since the APPN node was last reinitialized.\n          This counter is incremented whenever a condition is detected\n          that would cause a appnLsOperStateChangeTrap notification\n          to be sent, whether or not this notification is enabled.')
dlurDlusTableChanges = MibScalar((1, 3, 6, 1, 2, 1, 34, 4, 1, 7, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlurDlusTableChanges.setDescription('A count of the number of times a row in the dlurDlusTable\n          has changed status since the APPN node was last reinitialized.\n          This counter is incremented whenever a condition is detected\n          that would cause a dlurDlusStateChangeTrap notification\n          to be sent, whether or not this notification is enabled.')
appnTrapMibCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 34, 4, 3, 1, 2)).setObjects(*(("APPN-TRAP-MIB", "appnTrapMibIsrNotifGroup"), ("APPN-TRAP-MIB", "appnTrapMibTopoConfGroup"), ("APPN-TRAP-MIB", "appnTrapMibTopoNotifGroup"), ("APPN-TRAP-MIB", "appnTrapMibDlurConfGroup"), ("APPN-TRAP-MIB", "appnTrapMibDlurNotifGroup"),))
if mibBuilder.loadTexts: appnTrapMibCompliance.setDescription('The compliance statement for the SNMP entities that\n           implement the APPN-TRAP-MIB.')
appnTrapMibIsrNotifGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 34, 4, 3, 2, 21)).setObjects(*(("APPN-TRAP-MIB", "appnIsrAccountingDataTrap"),))
if mibBuilder.loadTexts: appnTrapMibIsrNotifGroup.setDescription("A notification for reporting the final values of the\n            APPN MIB's ISR counters.")
appnTrapMibTopoConfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 34, 4, 3, 2, 22)).setObjects(*(("APPN-TRAP-MIB", "appnTrapControl"), ("APPN-TRAP-MIB", "appnLocalTgTableChanges"), ("APPN-TRAP-MIB", "appnPortTableChanges"), ("APPN-TRAP-MIB", "appnLsTableChanges"),))
if mibBuilder.loadTexts: appnTrapMibTopoConfGroup.setDescription('A collection of objects for reducing the polling\n            associated with the local topology tables in the\n            APPN MIB.  Nodes that implement this group SHALL\n            also implement the appnTrapMibTopoNotifGroup.')
appnTrapMibTopoNotifGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 34, 4, 3, 2, 23)).setObjects(*(("APPN-TRAP-MIB", "appnLocalTgOperStateChangeTrap"), ("APPN-TRAP-MIB", "appnLocalTgCpCpChangeTrap"), ("APPN-TRAP-MIB", "appnPortOperStateChangeTrap"), ("APPN-TRAP-MIB", "appnLsOperStateChangeTrap"),))
if mibBuilder.loadTexts: appnTrapMibTopoNotifGroup.setDescription('A collection of notifications for reducing the polling\n            associated with the local topology tables in the\n            APPN MIB.  Nodes that implement this group SHALL\n            also implement the appnTrapMibTopoConfGroup.')
appnTrapMibDlurConfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 34, 4, 3, 2, 24)).setObjects(*(("APPN-TRAP-MIB", "appnTrapControl"), ("APPN-TRAP-MIB", "dlurDlusTableChanges"),))
if mibBuilder.loadTexts: appnTrapMibDlurConfGroup.setDescription('A collection of objects for reducing the polling\n            associated with the dlurDlusTable in the DLUR\n            MIB.  Nodes that implement this group SHALL also\n            implement the appnTrapMibDlurNotifGroup.')
appnTrapMibDlurNotifGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 34, 4, 3, 2, 25)).setObjects(*(("APPN-TRAP-MIB", "dlurDlusStateChangeTrap"),))
if mibBuilder.loadTexts: appnTrapMibDlurNotifGroup.setDescription('A notification for reducing the polling associated\n            with the dlurDlusTable in the DLUR MIB.  Nodes that\n            implement this group SHALL also implement the\n            appnTrapMibDlurConfGroup.')
mibBuilder.exportSymbols("APPN-TRAP-MIB", appnTrapMibTopoConfGroup=appnTrapMibTopoConfGroup, appnLocalTgCpCpChangeTrap=appnLocalTgCpCpChangeTrap, appnTrapMibTopoNotifGroup=appnTrapMibTopoNotifGroup, appnTrapMIB=appnTrapMIB, appnTrapControl=appnTrapControl, PYSNMP_MODULE_ID=appnTrapMIB, appnLsTableChanges=appnLsTableChanges, appnIsrAccountingDataTrap=appnIsrAccountingDataTrap, dlurDlusStateChangeTrap=dlurDlusStateChangeTrap, appnTrapObjects=appnTrapObjects, appnTrapMibCompliance=appnTrapMibCompliance, appnPortTableChanges=appnPortTableChanges, appnTrapMibIsrNotifGroup=appnTrapMibIsrNotifGroup, appnTrapMibDlurNotifGroup=appnTrapMibDlurNotifGroup, appnLocalTgTableChanges=appnLocalTgTableChanges, appnTrapMibDlurConfGroup=appnTrapMibDlurConfGroup, appnLocalTgOperStateChangeTrap=appnLocalTgOperStateChangeTrap, appnPortOperStateChangeTrap=appnPortOperStateChangeTrap, dlurDlusTableChanges=dlurDlusTableChanges, appnLsOperStateChangeTrap=appnLsOperStateChangeTrap)



#
# PySNMP MIB module ETHER-WIS (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ETHER-WIS
# Produced by pysmi-0.0.7 at Sun Feb 14 00:12:12 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ConstraintsIntersection, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint", "ConstraintsIntersection", "ValueRangeConstraint")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( Integer32, ModuleIdentity, Gauge32, Unsigned32, Bits, NotificationType, iso, transmission, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, MibIdentifier, IpAddress, Counter32, ObjectIdentity, TimeTicks, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "ModuleIdentity", "Gauge32", "Unsigned32", "Bits", "NotificationType", "iso", "transmission", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "MibIdentifier", "IpAddress", "Counter32", "ObjectIdentity", "TimeTicks")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
( sonetPathStuff2, sonetMediumLineType, sonetMediumType, sonetFarEndPathStuff2, sonetMediumLoopbackConfig, sonetSectionStuff2, sonetMediumLineCoding, sonetMediumCircuitIdentifier, sonetSESthresholdSet, sonetFarEndLineStuff2, sonetPathCurrentWidth, sonetLineStuff2, sonetMediumStuff2, ) = mibBuilder.importSymbols("SONET-MIB", "sonetPathStuff2", "sonetMediumLineType", "sonetMediumType", "sonetFarEndPathStuff2", "sonetMediumLoopbackConfig", "sonetSectionStuff2", "sonetMediumLineCoding", "sonetMediumCircuitIdentifier", "sonetSESthresholdSet", "sonetFarEndLineStuff2", "sonetPathCurrentWidth", "sonetLineStuff2", "sonetMediumStuff2")
etherWisMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 134)).setRevisions(("2003-09-19 00:00",))
if mibBuilder.loadTexts: etherWisMIB.setLastUpdated('200309190000Z')
if mibBuilder.loadTexts: etherWisMIB.setOrganization('IETF Ethernet Interfaces and Hub MIB\n                        Working Group')
if mibBuilder.loadTexts: etherWisMIB.setContactInfo('WG charter:\n                 http://www.ietf.org/html.charters/hubmib-charter.html\n\n               Mailing Lists:\n                 General Discussion: hubmib@ietf.org\n                 To Subscribe: hubmib-request@ietf.org\n                 In Body: subscribe your_email_address\n\n                Chair: Dan Romascanu\n               Postal: Avaya Inc.\n                       Atidim Technology Park, Bldg. 3\n                       Tel Aviv 61131\n                       Israel\n                  Tel: +972 3 645 8414\n               E-mail: dromasca@avaya.com\n\n               Editor: C. M. Heard\n               Postal: 600 Rainbow Dr. #141\n                       Mountain View, CA 94041-2542\n                       USA\n                  Tel: +1 650-964-8391\n               E-mail: heard@pobox.com')
if mibBuilder.loadTexts: etherWisMIB.setDescription("The objects in this MIB module are used in conjunction\n         with objects in the SONET-MIB and the MAU-MIB to manage\n         the Ethernet WAN Interface Sublayer (WIS).\n\n         The following reference is used throughout this MIB module:\n\n         [IEEE 802.3 Std] refers to:\n            IEEE Std 802.3, 2000 Edition: 'IEEE Standard for\n            Information technology - Telecommunications and\n            information exchange between systems - Local and\n            metropolitan area networks - Specific requirements -\n            Part 3: Carrier sense multiple access with collision\n            detection (CSMA/CD) access method and physical layer\n            specifications', as amended by IEEE Std 802.3ae-2002,\n            'IEEE Standard for Carrier Sense Multiple Access with\n            Collision Detection (CSMA/CD) Access Method and\n            Physical Layer Specifications - Media Access Control\n            (MAC) Parameters, Physical Layer and Management\n            Parameters for 10 Gb/s Operation', 30 August 2002.\n\n         Of particular interest are Clause 50, 'WAN Interface\n         Sublayer (WIS), type 10GBASE-W', Clause 30, '10Mb/s,\n         100Mb/s, 1000Mb/s, and 10Gb/s MAC Control, and Link\n         Aggregation Management', and Clause 45, 'Management\n         Data Input/Output (MDIO) Interface'.\n\n         Copyright (C) The Internet Society (2003).  This version\n         of this MIB module is part of RFC 3637;  see the RFC\n         itself for full legal notices.")
etherWisObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 1))
etherWisObjectsPath = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 2))
etherWisConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 3))
etherWisDevice = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 1, 1))
etherWisSection = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 1, 2))
etherWisPath = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 2, 1))
etherWisFarEndPath = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 2, 2))
etherWisDeviceTable = MibTable((1, 3, 6, 1, 2, 1, 10, 134, 1, 1, 1), )
if mibBuilder.loadTexts: etherWisDeviceTable.setDescription('The table for Ethernet WIS devices')
etherWisDeviceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 134, 1, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: etherWisDeviceEntry.setDescription('An entry in the Ethernet WIS device table.  For each\n          instance of this object there MUST be a corresponding\n          instance of sonetMediumEntry.')
etherWisDeviceTxTestPatternMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 1, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("squareWave", 2), ("prbs31", 3), ("mixedFrequency", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: etherWisDeviceTxTestPatternMode.setDescription('This variable controls the transmit test pattern mode.\n          The value none(1) puts the the WIS transmit path into\n          the normal operating mode.  The value squareWave(2) puts\n          the WIS transmit path into the square wave test pattern\n          mode described in [IEEE 802.3 Std.] subclause 50.3.8.1.\n          The value prbs31(3) puts the WIS transmit path into the\n          PRBS31 test pattern mode described in [IEEE 802.3 Std.]\n          subclause 50.3.8.2.  The value mixedFrequency(4) puts the\n          WIS transmit path into the mixed frequency test pattern\n          mode described in [IEEE 802.3 Std.] subclause 50.3.8.3.\n          Any attempt to set this object to a value other than\n          none(1) when the corresponding instance of ifAdminStatus\n          has the value up(1) MUST be rejected with the error\n          inconsistentValue, and any attempt to set the corresponding\n          instance of ifAdminStatus to the value up(1) when an\n          instance of this object has a value other than none(1)\n          MUST be rejected with the error inconsistentValue.')
etherWisDeviceRxTestPatternMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 1, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("prbs31", 3), ("mixedFrequency", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: etherWisDeviceRxTestPatternMode.setDescription('This variable controls the receive test pattern mode.\n          The value none(1) puts the the WIS receive path into the\n          normal operating mode.  The value prbs31(3) puts the WIS\n          receive path into the PRBS31 test pattern mode described\n          in [IEEE 802.3 Std.] subclause 50.3.8.2.  The value\n          mixedFrequency(4) puts the WIS receive path into the mixed\n          frequency test pattern mode described in [IEEE 802.3 Std.]\n          subclause 50.3.8.3.  Any attempt to set this object to a\n          value other than none(1) when the corresponding instance\n          of ifAdminStatus has the value up(1) MUST be rejected with\n          the error inconsistentValue, and any attempt to set the\n          corresponding instance of ifAdminStatus to the value up(1)\n          when an instance of this object has a value other than\n          none(1) MUST be rejected with the error inconsistentValue.')
etherWisDeviceRxTestPatternErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 1, 1, 1, 1, 3), Gauge32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: etherWisDeviceRxTestPatternErrors.setDescription('This object counts the number of errors detected when the\n          WIS receive path is operating in the PRBS31 test pattern\n          mode.  It is reset to zero when the WIS receive path\n          initially enters that mode, and it increments each time\n          the PRBS pattern checker detects an error as described in\n          [IEEE 802.3 Std.] subclause 50.3.8.2 unless its value is\n          65535, in which case it remains unchanged.  This object is\n          writeable so that it may be reset upon explicit request\n          of a command generator application while the WIS receive\n          path continues to operate in PRBS31 test pattern mode.')
etherWisSectionCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 134, 1, 2, 1), )
if mibBuilder.loadTexts: etherWisSectionCurrentTable.setDescription('The table for the current state of Ethernet WIS sections.')
etherWisSectionCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 134, 1, 2, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: etherWisSectionCurrentEntry.setDescription('An entry in the etherWisSectionCurrentTable.  For each\n          instance of this object there MUST be a corresponding\n          instance of sonetSectionCurrentEntry.')
etherWisSectionCurrentJ0Transmitted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 1, 2, 1, 1, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: etherWisSectionCurrentJ0Transmitted.setDescription("This is the 16-octet section trace message that\n          is transmitted in the J0 byte.  The value SHOULD\n          be '89'h followed by fifteen octets of '00'h\n          (or some cyclic shift thereof) when the section\n          trace function is not used, and the implementation\n          SHOULD use that value (or a cyclic shift thereof)\n          as a default if no other value has been set.")
etherWisSectionCurrentJ0Received = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 1, 2, 1, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16)).setMaxAccess("readonly")
if mibBuilder.loadTexts: etherWisSectionCurrentJ0Received.setDescription('This is the 16-octet section trace message that\n          was most recently received in the J0 byte.')
etherWisPathCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 134, 2, 1, 1), )
if mibBuilder.loadTexts: etherWisPathCurrentTable.setDescription('The table for the current state of Ethernet WIS paths.')
etherWisPathCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 134, 2, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: etherWisPathCurrentEntry.setDescription('An entry in the etherWisPathCurrentTable.  For each\n          instance of this object there MUST be a corresponding\n          instance of sonetPathCurrentEntry.')
etherWisPathCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 2, 1, 1, 1, 1), Bits().clone(namedValues=NamedValues(("etherWisPathLOP", 0), ("etherWisPathAIS", 1), ("etherWisPathPLM", 2), ("etherWisPathLCD", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: etherWisPathCurrentStatus.setDescription('This variable indicates the current status of the\n          path payload with a bit map that can indicate multiple\n          defects at once.  The bit positions are assigned as\n          follows:\n\n          etherWisPathLOP(0)\n             This bit is set to indicate that an\n             LOP-P (Loss of Pointer - Path) defect\n             is being experienced.  Note:  when this\n             bit is set, sonetPathSTSLOP MUST be set\n             in the corresponding instance of\n             sonetPathCurrentStatus.\n\n          etherWisPathAIS(1)\n             This bit is set to indicate that an\n             AIS-P (Alarm Indication Signal - Path)\n             defect is being experienced.  Note:  when\n             this bit is set, sonetPathSTSAIS MUST be\n             set in the corresponding instance of\n             sonetPathCurrentStatus.\n\n          etherWisPathPLM(1)\n             This bit is set to indicate that a\n             PLM-P (Payload Label Mismatch - Path)\n             defect is being experienced.  Note:  when\n             this bit is set, sonetPathSignalLabelMismatch\n             MUST be set in the corresponding instance of\n             sonetPathCurrentStatus.\n\n          etherWisPathLCD(3)\n             This bit is set to indicate that an\n             LCD-P (Loss of Codegroup Delination - Path)\n             defect is being experienced.  Since this\n             defect is detected by the PCS and not by\n             the path layer itself, there is no\n             corresponding bit in sonetPathCurrentStatus.')
etherWisPathCurrentJ1Transmitted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 2, 1, 1, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: etherWisPathCurrentJ1Transmitted.setDescription("This is the 16-octet path trace message that\n          is transmitted in the J1 byte.  The value SHOULD\n          be '89'h followed by fifteen octets of '00'h\n          (or some cyclic shift thereof) when the path\n          trace function is not used, and the implementation\n          SHOULD use that value (or a cyclic shift thereof)\n          as a default if no other value has been set.")
etherWisPathCurrentJ1Received = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 2, 1, 1, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16)).setMaxAccess("readonly")
if mibBuilder.loadTexts: etherWisPathCurrentJ1Received.setDescription('This is the 16-octet path trace message that\n          was most recently received in the J1 byte.')
etherWisFarEndPathCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 134, 2, 2, 1), )
if mibBuilder.loadTexts: etherWisFarEndPathCurrentTable.setDescription('The table for the current far-end state of Ethernet WIS\n          paths.')
etherWisFarEndPathCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 134, 2, 2, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: etherWisFarEndPathCurrentEntry.setDescription('An entry in the etherWisFarEndPathCurrentTable.  For each\n          instance of this object there MUST be a corresponding\n          instance of sonetFarEndPathCurrentEntry.')
etherWisFarEndPathCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 134, 2, 2, 1, 1, 1), Bits().clone(namedValues=NamedValues(("etherWisFarEndPayloadDefect", 0), ("etherWisFarEndServerDefect", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: etherWisFarEndPathCurrentStatus.setDescription('This variable indicates the current status at the\n          far end of the path using a bit map that can indicate\n          multiple defects at once.  The bit positions are\n          assigned as follows:\n\n          etherWisFarEndPayloadDefect(0)\n             A far end payload defect (i.e., far end\n             PLM-P or LCD-P) is currently being signaled\n             in G1 bits 5-7.\n\n          etherWisFarEndServerDefect(1)\n             A far end server defect (i.e., far end\n             LOP-P or AIS-P) is currently being signaled\n             in G1 bits 5-7.  Note:  when this bit is set,\n             sonetPathSTSRDI MUST be set in the corresponding\n             instance of sonetPathCurrentStatus.')
etherWisGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 3, 1))
etherWisCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 134, 3, 2))
etherWisDeviceGroupBasic = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 134, 3, 1, 1)).setObjects(*(("ETHER-WIS", "etherWisDeviceTxTestPatternMode"), ("ETHER-WIS", "etherWisDeviceRxTestPatternMode"),))
if mibBuilder.loadTexts: etherWisDeviceGroupBasic.setDescription('A collection of objects that support test\n          features required of all WIS devices.')
etherWisDeviceGroupExtra = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 134, 3, 1, 2)).setObjects(*(("ETHER-WIS", "etherWisDeviceRxTestPatternErrors"),))
if mibBuilder.loadTexts: etherWisDeviceGroupExtra.setDescription('A collection of objects that support\n          optional WIS device test features.')
etherWisSectionGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 134, 3, 1, 3)).setObjects(*(("ETHER-WIS", "etherWisSectionCurrentJ0Transmitted"), ("ETHER-WIS", "etherWisSectionCurrentJ0Received"),))
if mibBuilder.loadTexts: etherWisSectionGroup.setDescription('A collection of objects that provide\n          required information about a WIS section.')
etherWisPathGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 134, 3, 1, 4)).setObjects(*(("ETHER-WIS", "etherWisPathCurrentStatus"), ("ETHER-WIS", "etherWisPathCurrentJ1Transmitted"), ("ETHER-WIS", "etherWisPathCurrentJ1Received"),))
if mibBuilder.loadTexts: etherWisPathGroup.setDescription('A collection of objects that provide\n          required information about a WIS path.')
etherWisFarEndPathGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 134, 3, 1, 5)).setObjects(*(("ETHER-WIS", "etherWisFarEndPathCurrentStatus"),))
if mibBuilder.loadTexts: etherWisFarEndPathGroup.setDescription('A collection of objects that provide required\n          information about the far end of a WIS path.')
etherWisCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 134, 3, 2, 1)).setObjects(*(("ETHER-WIS", "etherWisDeviceGroupBasic"), ("ETHER-WIS", "etherWisSectionGroup"), ("ETHER-WIS", "etherWisPathGroup"), ("ETHER-WIS", "etherWisFarEndPathGroup"), ("SONET-MIB", "sonetMediumStuff2"), ("SONET-MIB", "sonetSectionStuff2"), ("SONET-MIB", "sonetLineStuff2"), ("SONET-MIB", "sonetFarEndLineStuff2"), ("SONET-MIB", "sonetPathStuff2"), ("SONET-MIB", "sonetFarEndPathStuff2"),))
if mibBuilder.loadTexts: etherWisCompliance.setDescription('The compliance statement for interfaces that include\n          the Ethernet WIS.  Compliance with the following\n          external compliance statements is prerequisite:\n\n          MIB Module             Compliance Statement\n          ----------             --------------------\n          IF-MIB                 ifCompliance3\n          IF-INVERTED-STACK-MIB  ifInvCompliance\n          EtherLike-MIB          dot3Compliance2\n          MAU-MIB                mauModIfCompl3')
mibBuilder.exportSymbols("ETHER-WIS", etherWisDeviceGroupExtra=etherWisDeviceGroupExtra, etherWisPath=etherWisPath, etherWisDeviceTxTestPatternMode=etherWisDeviceTxTestPatternMode, etherWisPathCurrentJ1Received=etherWisPathCurrentJ1Received, etherWisGroups=etherWisGroups, etherWisFarEndPath=etherWisFarEndPath, etherWisConformance=etherWisConformance, etherWisFarEndPathCurrentStatus=etherWisFarEndPathCurrentStatus, etherWisDeviceEntry=etherWisDeviceEntry, PYSNMP_MODULE_ID=etherWisMIB, etherWisFarEndPathCurrentTable=etherWisFarEndPathCurrentTable, etherWisMIB=etherWisMIB, etherWisPathCurrentJ1Transmitted=etherWisPathCurrentJ1Transmitted, etherWisObjects=etherWisObjects, etherWisSectionCurrentJ0Received=etherWisSectionCurrentJ0Received, etherWisPathGroup=etherWisPathGroup, etherWisSection=etherWisSection, etherWisSectionCurrentEntry=etherWisSectionCurrentEntry, etherWisFarEndPathCurrentEntry=etherWisFarEndPathCurrentEntry, etherWisDevice=etherWisDevice, etherWisSectionCurrentTable=etherWisSectionCurrentTable, etherWisDeviceRxTestPatternMode=etherWisDeviceRxTestPatternMode, etherWisDeviceRxTestPatternErrors=etherWisDeviceRxTestPatternErrors, etherWisCompliance=etherWisCompliance, etherWisDeviceGroupBasic=etherWisDeviceGroupBasic, etherWisSectionGroup=etherWisSectionGroup, etherWisFarEndPathGroup=etherWisFarEndPathGroup, etherWisPathCurrentStatus=etherWisPathCurrentStatus, etherWisPathCurrentTable=etherWisPathCurrentTable, etherWisDeviceTable=etherWisDeviceTable, etherWisObjectsPath=etherWisObjectsPath, etherWisSectionCurrentJ0Transmitted=etherWisSectionCurrentJ0Transmitted, etherWisPathCurrentEntry=etherWisPathCurrentEntry, etherWisCompliances=etherWisCompliances)



#
# PySNMP MIB module TCPIPX-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///home/tt/fixed_mibs/TCPIPX-MIB
# Produced by pysmi-0.0.2 at Mon Jun 22 23:55:14 2015
# On host cray platform Linux version 2.6.37.6-smp by user tt
# Using Python version 2.7.2 (default, Apr  2 2012, 20:32:47) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, MibTableRow, MibTableColumn, MibScalar, Unsigned32, TimeTicks, Counter64, MibTable, NotificationType, enterprises, ModuleIdentity, IpAddress, iso, Gauge32, MibIdentifier, Bits, ObjectIdentity, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "MibTableRow", "MibTableColumn", "MibScalar", "Unsigned32", "TimeTicks", "Counter64", "MibTable", "NotificationType", "enterprises", "ModuleIdentity", "IpAddress", "iso", "Gauge32", "MibIdentifier", "Bits", "ObjectIdentity", "Counter32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
class IpxAddress(OctetString):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(10,10)
    fixedLength = 10

novell = MibIdentifier((1, 3, 6, 1, 4, 1, 23))
mibDoc = MibIdentifier((1, 3, 6, 1, 4, 1, 23, 2))
tcpx = MibIdentifier((1, 3, 6, 1, 4, 1, 23, 2, 29))
tcpxTcp = MibIdentifier((1, 3, 6, 1, 4, 1, 23, 2, 29, 1))
tcpxUdp = MibIdentifier((1, 3, 6, 1, 4, 1, 23, 2, 29, 2))
tcpIpxConnTable = MibTable((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 1), )
if mibBuilder.loadTexts: tcpIpxConnTable.setDescription('A table containing information specific on\n                       TCP connection over IPX network layer.')
tcpIpxConnEntry = MibTableRow((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 1, 1), ).setIndexNames((0, "TCPIPX-MIB", "tcpIpxConnLocalAddress"), (0, "TCPIPX-MIB", "tcpIpxConnLocalPort"), (0, "TCPIPX-MIB", "tcpIpxConnRemAddress"), (0, "TCPIPX-MIB", "tcpIpxConnRemPort"))
if mibBuilder.loadTexts: tcpIpxConnEntry.setDescription('Information about a particular current TCP\n                       connection over IPX  An object of this type is\n                       transient, in that it ceases to exist when (or\n                       soon after) the connection makes the transition\n                       to the CLOSED state.')
tcpIpxConnState = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,)).clone(namedValues=NamedValues(("closed", 1), ("listen", 2), ("synSent", 3), ("synReceived", 4), ("established", 5), ("finWait1", 6), ("finWait2", 7), ("closeWait", 8), ("lastAck", 9), ("closing", 10), ("timeWait", 11), ("deleteTCB", 12),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: tcpIpxConnState.setDescription("The state of this TCP connection.\n\n                       The only value which may be set by a management\n                       station is deleteTCB(12).  Accordingly, it is\n                       appropriate for an agent to return a `badValue'\n                       response if a management station attempts to set\n                       this object to any other value.\n\n                       If a management station sets this object to the\n                       value deleteTCB(12), then this has the effect of\n                       deleting the TCB (as defined in RFC 793) of the\n                       corresponding connection on the managed node,\n                       resulting in immediate termination of the\n                       connection.\n\n                       As an implementation-specific option, a RST\n                       segment may be sent from the managed node to the\n                       other TCP endpoint (note however that RST\n                       segments are not sent reliably).")
tcpIpxConnLocalAddress = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 1, 1, 2), IpxAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpIpxConnLocalAddress.setDescription('The local IPX address for this TCP connection.\n                       In the case of a connection in the listen state\n                       which is willing to accept connections for any\n                       interface, the value 00000000:000000000000 is\n                       used.  See tcpUnspecConnTable for connections in\n                       the listen  state which is willing to accept\n                       connects for any IP interface associated with\n                       the node.')
tcpIpxConnLocalPort = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpIpxConnLocalPort.setDescription('The local port number for this TCP connection.')
tcpIpxConnRemAddress = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 1, 1, 4), IpxAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpIpxConnRemAddress.setDescription('The remote IPX address for this TCP connection.')
tcpIpxConnRemPort = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpIpxConnRemPort.setDescription('The remote port number for this TCP connection.')
udpIpxTable = MibTable((1, 3, 6, 1, 4, 1, 23, 2, 29, 2, 1), )
if mibBuilder.loadTexts: udpIpxTable.setDescription('A table containing UDP listener information.')
udpIpxEntry = MibTableRow((1, 3, 6, 1, 4, 1, 23, 2, 29, 2, 1, 1), ).setIndexNames((0, "TCPIPX-MIB", "udpIpxLocalAddress"), (0, "TCPIPX-MIB", "udpIpxLocalPort"))
if mibBuilder.loadTexts: udpIpxEntry.setDescription('Information about a particular current UDP\n                       listener.')
udpIpxLocalAddress = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 2, 1, 1, 1), IpxAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpIpxLocalAddress.setDescription('The local IPX address for this UDP listener.  In\n                       the case of a UDP listener which is willing to\n                       accept datagrams for any interface, the value\n                       00000000:000000000000 is used.  See\n                       udpUnspecTable for UDP listener which is\n                       willing to accept datagrams from any network\n                       layer.')
udpIpxLocalPort = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpIpxLocalPort.setDescription('The local port number for this UDP listener.')
tcpUnspecConnTable = MibTable((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 2), )
if mibBuilder.loadTexts: tcpUnspecConnTable.setDescription('A table containing information specific on\n                       TCP connection over unspecified network layer.')
tcpUnspecConnEntry = MibTableRow((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 2, 1), ).setIndexNames((0, "TCPIPX-MIB", "tcpUnspecConnLocalPort"))
if mibBuilder.loadTexts: tcpUnspecConnEntry.setDescription('Information about a particular current TCP\n                       connection over unspecified network layer.  An\n                       object of this type is transient, in that it\n                       ceases to exist when the connection makes\n                       transition beyond LISTEN state, or when (or\n                       soon after) the connection makes transition\n                       to the CLOSED state,')
tcpUnspecConnState = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 2, 1, 1), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 12,)).clone(namedValues=NamedValues(("closed", 1), ("listen", 2), ("deleteTCB", 12),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: tcpUnspecConnState.setDescription("The state of this TCP connection.\n\n                       Since the TCP connection can belong to this table\n                       only when its state is less than SYN-SENT, only\n                       closed and listen state apply.\n\n                       The only value which may be set by a management\n                       station is deleteTCB(12).  Accordingly, it is\n                       appropriate for an agent to return a `badValue'\n                       response if a management station attempts to set\n                       this object to any other value.\n\n                       If a management station sets this object to the\n                       value deleteTCB(12), then this has the effect of\n                       deleting the TCB (as defined in RFC 793) of the\n                       corresponding connection on the managed node,\n                       resulting in immediate termination of the\n                       connection.\n\n                       As an implementation-specific option, a RST\n                       segment may be sent from the managed node to the\n                       other TCP endpoint (note however that RST\n                       segments are not sent reliably).")
tcpUnspecConnLocalPort = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 1, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpUnspecConnLocalPort.setDescription('The local port number for this TCP connection.')
udpUnspecTable = MibTable((1, 3, 6, 1, 4, 1, 23, 2, 29, 2, 2), )
if mibBuilder.loadTexts: udpUnspecTable.setDescription('A table containing UDP listener information.')
udpUnspecEntry = MibTableRow((1, 3, 6, 1, 4, 1, 23, 2, 29, 2, 2, 1), ).setIndexNames((0, "TCPIPX-MIB", "udpUnspecLocalPort"))
if mibBuilder.loadTexts: udpUnspecEntry.setDescription('Information about a particular current UDP\n                       listener.')
udpUnspecLocalPort = MibTableColumn((1, 3, 6, 1, 4, 1, 23, 2, 29, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpUnspecLocalPort.setDescription('The local port number for this UDP listener.')
mibBuilder.exportSymbols("TCPIPX-MIB", tcpIpxConnTable=tcpIpxConnTable, IpxAddress=IpxAddress, udpIpxEntry=udpIpxEntry, udpIpxLocalPort=udpIpxLocalPort, udpUnspecEntry=udpUnspecEntry, udpIpxTable=udpIpxTable, tcpIpxConnLocalAddress=tcpIpxConnLocalAddress, novell=novell, tcpUnspecConnTable=tcpUnspecConnTable, tcpUnspecConnLocalPort=tcpUnspecConnLocalPort, tcpx=tcpx, udpUnspecTable=udpUnspecTable, tcpIpxConnEntry=tcpIpxConnEntry, udpIpxLocalAddress=udpIpxLocalAddress, tcpIpxConnState=tcpIpxConnState, udpUnspecLocalPort=udpUnspecLocalPort, tcpIpxConnLocalPort=tcpIpxConnLocalPort, tcpxTcp=tcpxTcp, tcpIpxConnRemAddress=tcpIpxConnRemAddress, tcpUnspecConnEntry=tcpUnspecConnEntry, tcpUnspecConnState=tcpUnspecConnState, mibDoc=mibDoc, tcpIpxConnRemPort=tcpIpxConnRemPort, tcpxUdp=tcpxUdp)



#
# PySNMP MIB module HPR-IP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/HPR-IP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:15:28 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( SnaControlPointName, ) = mibBuilder.importSymbols("APPN-MIB", "SnaControlPointName")
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint", "ValueRangeConstraint")
( hprObjects, hprGroups, hprCompliances, ) = mibBuilder.importSymbols("HPR-MIB", "hprObjects", "hprGroups", "hprCompliances")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Counter64, TimeTicks, NotificationType, Bits, Counter32, ObjectIdentity, Integer32, Gauge32, MibIdentifier, ModuleIdentity, IpAddress, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "TimeTicks", "NotificationType", "Bits", "Counter32", "ObjectIdentity", "Integer32", "Gauge32", "MibIdentifier", "ModuleIdentity", "IpAddress", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32")
( RowStatus, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TextualConvention", "DisplayString")
hprIp = ModuleIdentity((1, 3, 6, 1, 2, 1, 34, 6, 1, 5)).setRevisions(("1998-09-24 00:00",))
if mibBuilder.loadTexts: hprIp.setLastUpdated('9809240000Z')
if mibBuilder.loadTexts: hprIp.setOrganization('IETF SNA NAU MIB WG / AIW APPN MIBs SIG')
if mibBuilder.loadTexts: hprIp.setContactInfo('\n               Bob Clouston\n               Cisco Systems\n               7025 Kit Creek Road\n               P.O. Box 14987\n               Research Triangle Park, NC 27709, USA\n               Tel:    1 919 472 2333\n               E-mail: clouston@cisco.com\n\n               Bob Moore\n               IBM Corporation\n               4205 S. Miami Boulevard\n               BRQA/501\n               P.O. Box 12195\n               Research Triangle Park, NC 27709, USA\n               Tel:    1 919 254 4436\n               E-mail: remoore@us.ibm.com\n       ')
if mibBuilder.loadTexts: hprIp.setDescription('The MIB module for HPR over IP.  This module contains two\n       groups:\n\n        -  the HPR over IP Monitoring Group provides a count of the UDP\n           packets sent by a link station for each APPN traffic type.\n\n        -  the HPR over IP Configuration Group provides for reading and\n           setting the mappings between APPN traffic types and TOS\n           Precedence settings in the IP header.  These mappings are\n           configured at the APPN port level, and are inherited by the\n           APPN connection networks and link stations associated with an\n           APPN port.  A port-level mapping can, however, be overridden\n           for a particular connection network or link station.')
class AppnTrafficType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("low", 1), ("medium", 2), ("high", 3), ("network", 4), ("llcAndFnRoutedNlp", 5),)

class AppnTOSPrecedence(DisplayString, TextualConvention):
    subtypeSpec = DisplayString.subtypeSpec+ValueSizeConstraint(3,3)
    fixedLength = 3

hprIpActiveLsTable = MibTable((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 1), )
if mibBuilder.loadTexts: hprIpActiveLsTable.setDescription('The HPR/IP active link station table.  This table provides\n          counts of the number of UDP packets sent for each APPN\n          traffic type.')
hprIpActiveLsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 1, 1), ).setIndexNames((0, "HPR-IP-MIB", "hprIpActiveLsLsName"), (0, "HPR-IP-MIB", "hprIpActiveLsAppnTrafficType"))
if mibBuilder.loadTexts: hprIpActiveLsEntry.setDescription('Entry of the HPR/IP link station table.')
hprIpActiveLsLsName = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 1, 1, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(1,10)))
if mibBuilder.loadTexts: hprIpActiveLsLsName.setDescription('Administratively assigned name for the link station.  If this\n          object has the same value as the appnLsName in the APPN MIB,\n          then the two objects are referring to the same APPN link\n          station.')
hprIpActiveLsAppnTrafficType = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 1, 1, 2), AppnTrafficType())
if mibBuilder.loadTexts: hprIpActiveLsAppnTrafficType.setDescription('APPN traffic type being sent through the link station.')
hprIpActiveLsUdpPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprIpActiveLsUdpPackets.setDescription('The count of outgoing UDP packets carrying this type of APPN\n          traffic.  A discontinuity in the counter is indicated by the\n          appnLsCounterDisconTime object in the APPN MIB.')
hprIpAppnPortTable = MibTable((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 2), )
if mibBuilder.loadTexts: hprIpAppnPortTable.setDescription('The HPR/IP APPN port table.  This table supports reading and\n          setting the mapping between APPN traffic types and TOS\n          Precedence settings for all the link stations at this APPN\n          port.  This mapping can be overridden for an individual link\n          station or an individual connection network via, respectively,\n          the hprIpLsTOSPrecedence and the hprIpCnTOSPrecedence objects.')
hprIpAppnPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 2, 1), ).setIndexNames((0, "HPR-IP-MIB", "hprIpAppnPortName"), (0, "HPR-IP-MIB", "hprIpAppnPortAppnTrafficType"))
if mibBuilder.loadTexts: hprIpAppnPortEntry.setDescription('Entry of the HPR/IP APPN port table.  Entries exist for\n          every APPN port defined to support HPR over IP.')
hprIpAppnPortName = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 2, 1, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(1,10)))
if mibBuilder.loadTexts: hprIpAppnPortName.setDescription('Administratively assigned name for this APPN port.  If this\n          object has the same value as the appnPortName in the APPN MIB,\n          then the two objects are referring to the same APPN port.')
hprIpAppnPortAppnTrafficType = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 2, 1, 2), AppnTrafficType())
if mibBuilder.loadTexts: hprIpAppnPortAppnTrafficType.setDescription('APPN traffic type sent through the port.')
hprIpAppnPortTOSPrecedence = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 2, 1, 3), AppnTOSPrecedence()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hprIpAppnPortTOSPrecedence.setDescription('A setting for the three TOS Precedence bits in the IP Type of\n          Service field for this APPN traffic type.\n\n          When this value is changed via a Set operation, the new setting\n          for the TOS Precedence bits takes effect immediately, rather\n          than waiting for some event such as reinitialization of the\n          port or of the APPN node itself.')
hprIpLsTable = MibTable((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 3), )
if mibBuilder.loadTexts: hprIpLsTable.setDescription('The HPR/IP link station table.  Values for TOS Precedence at\n          the link station level override those at the level of the\n          containing port.  If there is no entry in this table for a\n          given link station, then that link station inherits its TOS\n          Precedence values from its port.')
hprIpLsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 3, 1), ).setIndexNames((0, "HPR-IP-MIB", "hprIpLsLsName"), (0, "HPR-IP-MIB", "hprIpLsAppnTrafficType"))
if mibBuilder.loadTexts: hprIpLsEntry.setDescription('Entry of the HPR/IP link station table.')
hprIpLsLsName = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 3, 1, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(1,10)))
if mibBuilder.loadTexts: hprIpLsLsName.setDescription('Administratively assigned name for the link station.  If this\n          object has the same value as the appnLsName in the APPN MIB,\n          then the two objects are referring to the same APPN link\n          station.')
hprIpLsAppnTrafficType = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 3, 1, 2), AppnTrafficType())
if mibBuilder.loadTexts: hprIpLsAppnTrafficType.setDescription('APPN traffic type sent through the link station.')
hprIpLsTOSPrecedence = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 3, 1, 3), AppnTOSPrecedence()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hprIpLsTOSPrecedence.setDescription('A setting for the three TOS Precedence bits in the IP Type of\n          Service field for this APPN traffic type.\n\n          When this value is changed via a Set operation, the new setting\n          for the TOS Precedence bits takes effect immediately, rather\n          than waiting for some event such as reinitialization of the\n          port or of the APPN node itself.')
hprIpLsRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 3, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hprIpLsRowStatus.setDescription("This object allows entries to be created and deleted in the\n          hprIpLsTable.  As soon as an entry becomes active, the mapping\n          between APPN traffic types and TOS Precedence settings that it\n          specifies becomes effective.\n\n          The value of the other accessible object in this entry,\n          hprIpLsTOSPrecedence, can be changed via a Set operation when\n          this object's value is active(1).\n\n          An entry in this table is deleted by setting this object to\n          destroy(6).  Deleting an entry in this table causes the\n          link station to revert to the default TOS Precedence\n          mapping for its port.")
hprIpCnTable = MibTable((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 4), )
if mibBuilder.loadTexts: hprIpCnTable.setDescription('The HPR/IP connection network table.  Values for TOS\n          Precedence at the connection network level override those at\n          the level of the containing port.  If there is no entry in\n          this table for a given connection network, then that\n          connection network inherits its TOS Precedence values from\n          its port.\n\n          A node may have connections to a given connection network\n          through multiple ports.  There is no provision in the HPR-IP\n          architecture for variations in TOS Precedence values for\n          a single connection network based on the port through which\n          traffic is flowing to the connection network.  Thus an entry\n          in this table overrides the port-level settings for all the\n          ports through which the node can reach the connection\n          network.')
hprIpCnEntry = MibTableRow((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 4, 1), ).setIndexNames((0, "HPR-IP-MIB", "hprIpCnVrnName"), (0, "HPR-IP-MIB", "hprIpCnAppnTrafficType"))
if mibBuilder.loadTexts: hprIpCnEntry.setDescription('Entry of the HPR/IP connection network table.')
hprIpCnVrnName = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 4, 1, 1), SnaControlPointName())
if mibBuilder.loadTexts: hprIpCnVrnName.setDescription('SNA control point name of the virtual routing node (VRN) that\n          identifies the connection network in the APPN topology\n          database.  If this object has the same value as the appnVrnName\n          in the APPN MIB, then the two objects are referring\n          to the same APPN VRN.')
hprIpCnAppnTrafficType = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 4, 1, 2), AppnTrafficType())
if mibBuilder.loadTexts: hprIpCnAppnTrafficType.setDescription('APPN traffic type sent to this connection network.')
hprIpCnTOSPrecedence = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 4, 1, 3), AppnTOSPrecedence()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hprIpCnTOSPrecedence.setDescription('A setting for the three TOS Precedence bits in the IP Type of\n          Service field for this APPN traffic type.  This setting applies\n          to all traffic sent to this connection network by this node,\n          regardless of the port through which the traffic is sent.\n\n          When this value is changed via a Set operation, the new setting\n          for the TOS Precedence bits takes effect immediately, rather\n          than waiting for some event such as reinitialization of a\n          port or of the APPN node itself.')
hprIpCnRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 5, 4, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hprIpCnRowStatus.setDescription("This object allows entries to be created and deleted in the\n          hprIpCnTable.  As soon as an entry becomes active, the mapping\n          between APPN traffic types and TOS Precedence settings that it\n          specifies becomes effective.\n\n          The value of the other accessible object in this entry,\n          hprIpCnTOSPrecedence, can be changed via a Set operation when\n          this object's value is active(1).\n\n          An entry in this table is deleted by setting this object to\n          destroy(6).  Deleting an entry in this table causes the\n          connection network to revert to the default TOS Precedence\n          mapping for each port through which it is accessed.")
hprIpCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 34, 6, 2, 1, 2)).setObjects(*(("HPR-IP-MIB", "hprIpMonitoringGroup"), ("HPR-IP-MIB", "hprIpConfigurationGroup"),))
if mibBuilder.loadTexts: hprIpCompliance.setDescription('Compliance statement for the HPR over IP MIB module.')
hprIpMonitoringGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 34, 6, 2, 2, 5)).setObjects(*(("HPR-IP-MIB", "hprIpActiveLsUdpPackets"),))
if mibBuilder.loadTexts: hprIpMonitoringGroup.setDescription('An object for counting outgoing HPR/IP traffic for each APPN\n          traffic type.')
hprIpConfigurationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 34, 6, 2, 2, 6)).setObjects(*(("HPR-IP-MIB", "hprIpAppnPortTOSPrecedence"), ("HPR-IP-MIB", "hprIpLsTOSPrecedence"), ("HPR-IP-MIB", "hprIpLsRowStatus"), ("HPR-IP-MIB", "hprIpCnTOSPrecedence"), ("HPR-IP-MIB", "hprIpCnRowStatus"),))
if mibBuilder.loadTexts: hprIpConfigurationGroup.setDescription('A collection of HPR/IP objects representing the mappings\n          between APPN traffic types and TOS Precedence bits at the APPN\n          port, APPN link station, and APPN connection network levels.')
mibBuilder.exportSymbols("HPR-IP-MIB", hprIpLsTOSPrecedence=hprIpLsTOSPrecedence, hprIpAppnPortTOSPrecedence=hprIpAppnPortTOSPrecedence, hprIpLsRowStatus=hprIpLsRowStatus, hprIpCompliance=hprIpCompliance, hprIpAppnPortName=hprIpAppnPortName, hprIpActiveLsEntry=hprIpActiveLsEntry, hprIpAppnPortTable=hprIpAppnPortTable, hprIpLsTable=hprIpLsTable, hprIpCnAppnTrafficType=hprIpCnAppnTrafficType, hprIpCnVrnName=hprIpCnVrnName, hprIpCnTable=hprIpCnTable, PYSNMP_MODULE_ID=hprIp, hprIpActiveLsLsName=hprIpActiveLsLsName, hprIpCnEntry=hprIpCnEntry, hprIpConfigurationGroup=hprIpConfigurationGroup, hprIpCnRowStatus=hprIpCnRowStatus, AppnTrafficType=AppnTrafficType, hprIpMonitoringGroup=hprIpMonitoringGroup, hprIpActiveLsUdpPackets=hprIpActiveLsUdpPackets, hprIpActiveLsAppnTrafficType=hprIpActiveLsAppnTrafficType, hprIpLsEntry=hprIpLsEntry, hprIpLsAppnTrafficType=hprIpLsAppnTrafficType, hprIpAppnPortAppnTrafficType=hprIpAppnPortAppnTrafficType, hprIpCnTOSPrecedence=hprIpCnTOSPrecedence, hprIpLsLsName=hprIpLsLsName, hprIpAppnPortEntry=hprIpAppnPortEntry, AppnTOSPrecedence=AppnTOSPrecedence, hprIpActiveLsTable=hprIpActiveLsTable, hprIp=hprIp)
